@@ -1,6 +1,6 @@
 """Module for plotting Numpy-like 1D histograms to the terminal."""
 
-
+import shutil
 from itertools import cycle
 from typing import Optional
 
@@ -253,6 +253,9 @@ class BinFormatter:
         else:
             scale = self.scale
 
+        if scale == 0:
+            scale = 1.0
+
         # Calculate bin heights in characters
         heights = [int(c // scale) for c in counts]
 
@@ -364,7 +367,7 @@ class HistFormatter:
         self.title = title
         self.edges = edges
         # Fit histograms into the terminal, unless otherwise specified
-        term_size = click.get_terminal_size()
+        term_size = shutil.get_terminal_size()
         if columns is None:
             columns = term_size[0] - 1
         if lines is None:
@@ -384,7 +387,7 @@ class HistFormatter:
         if self.summary:
             # Make room for a summary at the bottom
             self.hist_lines -= 4
-        elif any([len(l) > 0 for l in self.labels]):
+        elif any(len(lab) > 0 for lab in self.labels):
             # Make room for a legend at the bottom
             self.hist_lines -= 1
 
@@ -399,6 +402,8 @@ class HistFormatter:
             # so all bins will scale to <= 1 lines
             # and be rendered with one line
             line_scale = np.max(edges[1:] - edges[:-1])
+        if line_scale == 0.0:
+            line_scale = 1.0
         self.bin_lines = ((edges[1:] - edges[:-1]) // line_scale).astype(int)
         self.bin_lines = np.where(self.bin_lines, self.bin_lines, 1)
         self.bin_formatter = BinFormatter(**kwargs)
@@ -465,7 +470,7 @@ class HistFormatter:
 
         if self.summary:
             hist_string += self.summarize(counts, top, bottom)
-        elif any([len(l) > 0 for l in self.labels]):
+        elif any(len(lab) > 0 for lab in self.labels):
             hist_string += self.summarize(counts, top, bottom, legend_only=True)
 
         return hist_string
@@ -480,7 +485,7 @@ class HistFormatter:
 
         # First line: symbol, label
         summary += "     "
-        for _, l, s, fg, bg in zip(
+        for _, lab, s, fg, bg in zip(
             counts,
             cycle(self.labels),
             cycle(self.bin_formatter.symbols),
@@ -488,13 +493,13 @@ class HistFormatter:
             cycle(self.bin_formatter.bg_colors),
         ):
             # Pad label to make room for numbers below
-            l = f"{l:<9}"
+            lab = f"{lab:<9}"
             label = " "
             label += Hixel(
                 s, fg, bg, self.bin_formatter.use_color, self.bin_formatter.compose
             ).render()
-            label += " " + l
-            label_widths.append(3 + len(l))
+            label += " " + lab
+            label_widths.append(3 + len(lab))
             summary += label
         pad = max(self.columns - (5 + np.sum(label_widths)), 0) // 2
         summary = " " * pad + summary
@@ -513,15 +518,21 @@ class HistFormatter:
         # Third line: Average
         summary += " " * pad + "Avg:"
         for c, w in zip(counts, label_widths):
-            average = np.average(bin_values, weights=c)
+            try:
+                average = np.average(bin_values, weights=c)
+            except ZeroDivisionError:
+                average = np.nan
             summary += f" {average: .2e}" + " " * (w - 10)
         summary += "\n"
 
         # Fourth line: std
         summary += " " * pad + "Std:"
         for c, w in zip(counts, label_widths):
-            average = np.average(bin_values, weights=c)
-            std = np.sqrt(np.average((bin_values - average) ** 2, weights=c))
+            try:
+                average = np.average(bin_values, weights=c)
+                std = np.sqrt(np.average((bin_values - average) ** 2, weights=c))
+            except ZeroDivisionError:
+                std = np.nan
             summary += f" {std: .2e}" + " " * (w - 10)
         summary += "\n"
 
